using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using RenovationWorkContracts.BindingModels;
using RenovationWorkContracts.SearchModels;
using RenovationWorkContracts.StoragesContracts;
using RenovationWorkContracts.ViewModels;
using RenovationWorkDatabaseImplement.Models;
using Microsoft.EntityFrameworkCore;

namespace RenovationWorkDatabaseImplement.Implements
{
    public class OrderStorage : IOrderStorage
    {
        public List<OrderViewModel> GetFullList()
        {
            using var context = new RenovationWorkDatabase();
            return context.Orders
                     .Include(x => x.Repair)
                     .Include(x => x.Client)
                     .Select(x => x.GetViewModel)
                     .ToList();
        }

        public List<OrderViewModel> GetFilteredList(OrderSearchModel model)
        {
            using var context = new RenovationWorkDatabase();
            var result = context.Orders.Include(x => x.Repair).Include(x => x.Client).Where(x => (
                            (!model.Id.HasValue || x.Id == model.Id) &&
                            (!model.DateFrom.HasValue || x.DateCreate >= model.DateFrom) &&
                            (!model.DateTo.HasValue || x.DateCreate <= model.DateTo) &&
                            (!model.ClientId.HasValue || x.ClientId == model.ClientId)
                        )
                    )
                    .Select(x => x.GetViewModel)
                    .ToList();
            return result;
        }

        public OrderViewModel? GetElement(OrderSearchModel model)
        {
            if (!model.Id.HasValue)
            {
                return new();
            }
            using var context = new RenovationWorkDatabase();
            return context.Orders.Include(x => x.Repair).Include(x => x.Client).FirstOrDefault(x => x.Id == model.Id)?.GetViewModel;
        }

        public OrderViewModel? Insert(OrderBindingModel model)
        {
            using var context = new RenovationWorkDatabase();
            if (model == null)
                return null;
            var newOrder = Order.Create(context, model);
            if (newOrder == null)
            {
                return null;
            }
            context.Orders.Add(newOrder);
            context.SaveChanges();
            return newOrder.GetViewModel;
        }

        public OrderViewModel? Update(OrderBindingModel model)
        {
            using var context = new RenovationWorkDatabase();
            var order = context.Orders.Include(x => x.Repair)
                    .Include(x => x.Client)
                    .FirstOrDefault(x => x.Id == model.Id);
            if (order == null)
            {
                return null;
            }
            order.Update(model);
            context.SaveChanges();
            return order.GetViewModel;
        }

        public OrderViewModel? Delete(OrderBindingModel model)
        {
            using var context = new RenovationWorkDatabase();
            var order = context.Orders
                    .Include(x => x.Repair)
                    .Include(x => x.Client)
                    .FirstOrDefault(rec => rec.Id == model.Id);
            if (order != null)
            {
                context.Orders.Remove(order);
                context.SaveChanges();
                return order.GetViewModel;
            }
            return null;
        }
    }
}
