using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using RenovationWorkContracts.BindingModels;
using RenovationWorkContracts.SearchModels;
using RenovationWorkContracts.ViewModels;

namespace RenovationWorkContracts.StoragesContracts
{
    public interface IRepairStorage
    {
        List<RepairViewModel> GetFullList();
        List<RepairViewModel> GetFilteredList(RepairSearchModel model);
        RepairViewModel? GetElement(RepairSearchModel model);
        RepairViewModel? Insert(RepairBindingModel model);
        RepairViewModel? Update(RepairBindingModel model);
        RepairViewModel? Delete(RepairBindingModel model);
    }
}
